# Window Manager and desktop programs
{ config, lib, pkgs, ... }:
let
  unstableTarball =
    fetchTarball
      https://github.com/NixOS/nixpkgs/archive/nixos-unstable.tar.gz;
in
{
  sound.enable = true;
  hardware.pulseaudio.enable = false;
  security.rtkit.enable = true;

  services = {
    #blueman.enable = true;
    #openvpn.restartAfterSleep = false;
    openvpn.servers = {
      arn  = { 
        config = '' config /home/mrflos/Nextcloud/vpn\ ARN/2023/vpn510.conf ''; 
        autoStart = false;
      };
    };
    pipewire = {
      enable = true;
      alsa.enable = true;
      alsa.support32Bit = true;
      pulse.enable = true;
      # If you want to use JACK applications, uncomment this
      #jack.enable = true;

      # use the example session manager (no others are packaged yet so this is enabled by default,
      # no need to redefine it in your config for now)
      #media-session.enable = true;
    };
    printing.enable = true; # Enable CUPS to print documents.
    xserver = {
      enable = true;
      layout = "us";
      # desktopManager.gnome.enable = true;
      desktopManager.plasma5.enable = true;
      displayManager.sddm.enable = true;
      # libinput.enable = true; # Enable touchpad support (enabled default in most desktopManager).
    };
  };

  programs = {
    chromium = {
      enable = true;
      homepageLocation = "about:blank";

      extensions = [
        "pejkokffkapolfffcgbmdmhdelanoaih" # Unsplash instant
        "cjpalhdlnbpafiamejdnhcphjbkeiagm" # uBlock Origin
        "gfapcejdoghpoidkfodoiiffaaibpaem" # Dracula theme
        "jbbplnpkjmmeebjpijfedlgcdilocofh" # wave a11y
      ];

      extraOpts = {
        SpellcheckEnabled = true;
        SpellcheckLanguage = [
          "fr-FR"
          "en-GB"
          "ru"
        ];
      };
    };
    dconf.enable = true;
    droidcam.enable = true;
    firefox.enable = true;
    kdeconnect.enable = true;
    ssh.askPassword = pkgs.lib.mkForce "${pkgs.ksshaskpass.out}/bin/ksshaskpass"; # conflict between kde and gnome cf. https://github.com/NixOS/nixpkgs/issues/75867
    ssh.startAgent = true;
    steam.enable = true;
  };

  # Allow unfree packages
  nixpkgs.config.allowUnfree = true;
  # nixpkgs.config = {
  #   packageOverrides = pkgs: with pkgs; {
  #     unstable = import unstableTarball {
  #       config = config.nixpkgs.config;
  #     };
  #   };
  # };

  environment.plasma5.excludePackages = with pkgs.libsForQt5; [
    baloo
    elisa
    gwenview
    khelpcenter
    oxygen
    plasma-browser-integration
  ];
  # List packages installed in system profile. To search, run:
  # $ nix search wget
  environment.systemPackages = with pkgs; [
    (vscode-with-extensions.override {
      vscode = vscodium;
      vscodeExtensions = with vscode-extensions; [
        bmewburn.vscode-intelephense-client
        dracula-theme.theme-dracula
        gruntfuggly.todo-tree
        jnoortheen.nix-ide
        #junstyle.php-cs-fixer
        mhutchie.git-graph
        ms-ceintl.vscode-language-pack-fr
      ]
      ++ pkgs.vscode-utils.extensionsFromVscodeMarketplace [
      {
        name = "twig-language-2";
        publisher = "mblode";
        version = "2.1.14";
        sha256 = "113w2iis4zi4z3sqc3vd2apyrh52hbh2gvmxjr5yvjpmrsksclbd";
      }
      ]
      ;
    })
    (chromium.override {
      enableWideVine = true; # DRM support
    })
    bitwarden
    calibre
    digikam
    dracula-theme
    #palenight-theme
    numix-cursor-theme
    papirus-icon-theme
    element-desktop
    filezilla
    gimp-with-plugins
    #hyprland
    inkscape-with-extensions
    joplin-desktop
    #keychain
    kitty
    kitty-themes
    latte-dock
    libreoffice
    libsForQt5.ark
    libsForQt5.bismuth
    mattermost-desktop
    mixxx
    nextcloud-client
    obsidian
    signal-desktop
    tdesktop #telegram
    thunderbird
    transmission-qt
    vlc
    yt-dlp
  ];

  # environment.gnome.excludePackages = (with pkgs; [
  #   gnome-photos
  #   gnome-tour
  # ]) ++ (with pkgs.gnome; [
  #   cheese # webcam tool
  #   gnome-music
  #   gedit # text editor
  #   epiphany # web browser
  #   geary # email reader
  #   gnome-characters
  #   tali # poker game
  #   iagno # go game
  #   hitori # sudoku game
  #   atomix # puzzle game
  #   yelp # Help view
  #   gnome-contacts
  #   gnome-initial-setup
  # ]);
  
  # Do not restart the display manager automatically
  systemd.services.display-manager.restartIfChanged = lib.mkForce false;

  # If something needs more than 20s to stop it should probably be
  # killed.
  systemd.extraConfig = ''
    DefaultTimeoutStopSec=20s
  '';
}
